@@ -1,7 +1,7 @@
 from .registered_task import RegisteredTask, MockTask, PrintTask
 from .taskqueue import (
   TaskQueue, MockTaskQueue, GreenTaskQueue, LocalTaskQueue, 
-  multiprocess_upload, QueueEmptyError, totask
+  multiprocess_upload, QueueEmptyError, totask, UnsupportedProtocolError
 )
 
-__version__ = '2.1.0'
\ No newline at end of file
+__version__ = '2.3.0'
\ No newline at end of file
