@@ -1,7 +1,3 @@
-from __future__ import print_function
-
-import six
-
 import copy
 from functools import partial
 import json
@@ -37,6 +33,9 @@ def totalfn(iterator, total):
   except TypeError:
     return None
 
+class UnsupportedProtocolError(BaseException):
+  pass
+
 class QueueEmptyError(LookupError):
   pass
 
@@ -88,7 +87,7 @@ class TaskQueue(object):
     elif path.protocol == 'fq':
       return FileQueueAPI(path.path)
     else:
-      raise ValueError('Unsupported protocol ' + str(self.path.protocol))
+      raise UnsupportedProtocolError('Unsupported protocol ' + str(self.path.protocol))
 
   def check_monkey_patch_status(self):
     import gevent.monkey
@@ -145,6 +144,13 @@ class TaskQueue(object):
     return [ totask(x) for x in iter(self.api) ]
 
   def insert(self, tasks, delay_seconds=0, total=None, parallel=1):
+    if isinstance(tasks, TaskQueue):
+      taskgen = tasks.tasks()
+      if not isinstance(taskgen, TaskQueue):
+        return self.insert(taskgen, delay_seconds, total, parallel)
+      else:
+        raise ValueError(str(tasks) + " would have caused an infinite recursion by returning a TaskQueue object from obj.tasks()")
+    
     tasks = toiter(tasks)
     total = totalfn(tasks, total)
 
@@ -169,6 +175,10 @@ class TaskQueue(object):
     ct_lock = threading.Lock()
     def insertfn(batch, ct):
       try:
+        # Set incr = 0 first because 
+        # UnboundLocalError: local variable 'incr' referenced before assignment 
+        # when e.g. OSError: [Errno 28] No space left on device
+        incr = 0 
         incr = self.api.insert(batch, delay_seconds) 
       finally:
         with ct_lock:
@@ -256,6 +266,19 @@ class TaskQueue(object):
         self.wait()
       return self
 
+  def tasks(self):
+    """
+    Iterate over all tasks.
+
+    Can cause infinite loops on SQS and so is not
+    supported. You can use the api method directly 
+    if you know what you're doing.
+    """
+    if self.path.protocol == "sqs":
+      raise UnsupportedProtocolError("SQS could enter an infinite loop from this method.")
+
+    return ( totask(task) for task in iter(self.api) )
+
   def poll(
     self, lease_seconds=LEASE_SECONDS,  
     verbose=False, execute_args=[], execute_kwargs={}, 
